@@ -1,23 +1,8 @@
 /*
- * Copyright (C) 2008,2009,2010,2012,2013,2016,2017
- *               Rolf Eike Beer <kde@opensource.sf-tec.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2012, 2013, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 #include "KGpgRootNode.h"
 
 #include "KGpgGroupNode.h"
@@ -61,11 +46,7 @@ KGpgRootNode::addGroups(const QStringList &groups)
 		if (parts.count() < 2)
 			continue;
 		const QString groupName = parts.first();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-		new KGpgGroupNode(this, groupName, parts.at(1).split(QLatin1Char(';'), QString::SkipEmptyParts));
-#else
 		new KGpgGroupNode(this, groupName, parts.at(1).split(QLatin1Char(';'), Qt::SkipEmptyParts));
-#endif
 	}
 }
 
@@ -87,7 +68,7 @@ KGpgRootNode::addKeys(const QStringList &ids)
 		}
 
 		KGpgKeyNode *nd = new KGpgKeyNode(this, key);
-		emit newKeyNode(nd);
+		Q_EMIT newKeyNode(nd);
 	}
 
 	for (const KgpgCore::KgpgKey &key : qAsConst(secretlist))
